@@ -1,6 +1,5 @@
 package Test::Mockify::TypeTests;
 use strict;
-use warnings;
 use Scalar::Util qw ( blessed );
 use base qw( Exporter );
 our @EXPORT_OK = qw (
@@ -10,19 +9,18 @@ our @EXPORT_OK = qw (
         IsArrayReference
         IsHashReference
         IsObjectReference
-        IsCodeReference
     );
 
+use Test::More;
 #------------------------------------------------------------------------
 sub IsInteger {
     my ( $Value ) = @_;
 
     my $IsInteger = 0;
     my $Sign = '[-+]?'; # + or - or nothing
-	if( defined $Value ){
-	    if($Value =~ /^$Sign\d+$/ ) {
-	        $IsInteger = 1;
-		}
+
+    if( $Value =~ /^$Sign\d+$/ ) {
+        $IsInteger = 1;
     }
 
     return $IsInteger;
@@ -38,8 +36,7 @@ sub IsFloat {
     my $OptionalExponent = '([eE][-+]?\d+)?';
     my $FloatRegex = sprintf('%s%s%s', $OptionalSign, $NumberOptions, $OptionalExponent);
 
-	
-    if ( $Value && $Value =~ /^$FloatRegex$/ ){
+    if ( $Value =~ /^$FloatRegex$/ ){
         $IsFloat = 1;
     }
 
@@ -89,18 +86,6 @@ sub IsHashReference {
     return $IsHash;
 }
 #------------------------------------------------------------------------
-sub IsCodeReference {
-    my ( $hValue ) = @_;
-
-    my $IsCode = 0;
-
-    if ( ref($hValue) eq 'CODE' ) {
-        $IsCode = 1;
-    }
-
-    return $IsCode;
-}
-#------------------------------------------------------------------------
 sub IsObjectReference {
     my ( $Value ) = @_;
 
@@ -112,5 +97,4 @@ sub IsObjectReference {
 
     return $IsObject;
 }
-
 1;
