@@ -21,7 +21,6 @@ use Scalar::Util qw( blessed );
 use base qw ( Exporter );
 
 use strict;
-use warnings;
 
 our @EXPORT_OK = qw (
     GetParametersFromMockifyCall
@@ -117,17 +116,3 @@ sub _TestMockifyObject {
 }
 
 1;
-__END__
-
-=head1 LICENSE
-
-Copyright (C) 2017 ePages GmbH
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Christian Breitkreutz E<lt>cbreitkreutz@epages.comE<gt>
-
-=cut
\ No newline at end of file
